import 'package:flutter/material.dart';
import 'package:hometec_ui/components/button/button.dart';
import 'package:hometec_ui/components/progress_bar/loading_progress_bar.dart';
import 'package:hometec_ui/components/state_list/model/state_list_model.dart';
import 'package:hometec_ui/resources/colors/color.dart';
import 'package:hometec_ui/resources/fonts/font.dart';

class StateList extends StatefulWidget {

  final Widget child;
  final Stream<StateListEnum> state;
  final String emptyMessage;
  final String errorMessage;
  final String networkMessage;
  final Widget other;
  final Function onRefresh;
  final Key onRefreshKey;
  final String onRefreshTitle;

  const StateList({Key key, @required this.child, @required this.state, @required this.emptyMessage, @required this.errorMessage, this.other, this.onRefresh, this.onRefreshKey, this.networkMessage, this.onRefreshTitle}) : super(key: key);

  @override
  _StateListState createState() => _StateListState(child, state, other, onRefresh, onRefreshKey);
}

class _StateListState extends State<StateList> {
  final Widget child;
  final Stream<StateListEnum> state;
  final Widget other;
  final Function onRefresh;
  final Key onRefreshKey;

  _StateListState(this.child, this.state, this.other, this.onRefresh, this.onRefreshKey);

  @override
  Widget build(BuildContext context) {
    return StreamBuilder(
      stream: state,
      builder: (context, snapshot){
        if(snapshot.hasData)
          switch (snapshot.data) {
            case StateListEnum.success:
              return Container(
                child: child
              );
            case StateListEnum.other:
              return Container(
                child: other
              );
            case StateListEnum.empty:
              return Padding(
                  padding: EdgeInsets.all(24),
                  child: Center(
                    child: Text(widget.emptyMessage, textAlign: TextAlign.center, style: Font.bodyRegular.style(color: ECColor.textColor),),
                  )
                );
            case StateListEnum.error:
              return Padding(
                padding: EdgeInsets.all(24),
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    children: <Widget>[
                      Icon(Icons.report_problem, size: 72, color: ECColor.textColor),
                      SizedBox(height: 8),
                      Text(widget.errorMessage, textAlign: TextAlign.center, style: Font.bodyRegular.style(color: ECColor.textColor),),
                      //SizedBox(height: 8),
                      //ECButton(widget.onRefreshTitle, onPressed: onRefresh,)
                    ],
                  )
                );             
            case StateListEnum.network:
              return Padding(
                padding: EdgeInsets.all(24),
                  child: Center(
                    child: Column(
                      mainAxisSize: MainAxisSize.min,
                      children: <Widget>[
                        Icon(Icons.signal_wifi_off, size: 72, color: ECColor.textColor),
                        SizedBox(height: 8),
                        Text(widget.networkMessage, textAlign: TextAlign.center, style: Font.bodyRegular.style(color: ECColor.textColor),),
                        //SizedBox(height: 8),
                        //ECButton(widget.onRefreshTitle, onPressed: onRefresh,)
                      ],
                    ),
                  )
                );
            default:
              return Container(
                constraints: BoxConstraints(
                  minHeight: 200
                ),
                child: Center(
                  child: LoadingProgressBar(),
                ),
              );
          }
        else
          return Container(
            constraints: BoxConstraints(
              minHeight: 200
            ),
            child: Center(
              child: LoadingProgressBar(),
            ),
          );
      }
    );
  }
}